/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.gui;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.tree.TreePath;

import ch.cern.lhcb.xmleditor.undo.CompoundEdit;
import ch.cern.lhcb.xmleditor.xerces.ElementImpl;
import ch.cern.lhcb.xmleditor.xerces.TreeElement;

/**
 * this is an implementation of KeyListener that only deals with the hit of the
 * DEL key
 * 
 * @author Sebastien Ponce
 */
public class XmlKeyListener implements KeyListener {

    /**
     * the Xml tree this listener is listening at
     */
    private XmlTree jTree;

    /**
     * constructor
     * 
     * @param jTree the XmlTree this listener will listen at
     */
    public XmlKeyListener(XmlTree jTree) {
        this.jTree = jTree;
    }

    /**
     * Invoked when a key has been typed. This event occurs when a key press is
     * followed by a key release.
     * 
     * @param e the event
     */
    public void keyTyped(KeyEvent e) {
        // nothing to do
        // all was done in keyReleased
    }

    /**
     * Invoked when a key has been pressed.
     * 
     * @param e the event
     */
    public void keyPressed(KeyEvent e) {
        // nothing to do
    }

    /**
     * Invoked when a key has been released.
     * 
     * @param e the event
     */
    public void keyReleased(KeyEvent e) {
        // if the user hit the DEL key
        if (e.getKeyCode() == KeyEvent.VK_DELETE) {
            // begins a compoundedit in undo manager since we delete several
            // nodes at once
            CompoundEdit edit = new CompoundEdit(jTree.getTreeView()
                    .getEditor());
            jTree.getTreeView().getEditor().getUndoManager().addEdit(edit);
            // gets the node to be removed
            TreePath[] treePaths = jTree.getSelectionPaths();
            if (treePaths != null) {
                for (int i = 0; i < treePaths.length; i++) {
                    TreeElement node = ((XmlTreeNode) treePaths[i]
                            .getLastPathComponent()).getNode();
                    // gets the parent
                    ElementImpl parent = (ElementImpl) node.getParentNode();
                    // removes the node from the document
                    parent.undoableRemoveChild(node);
                }
            }
            // closes the compound edit
            edit.end();
        }
    }

}