/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.xerces;

import org.apache.xerces.parsers.DOMParser;

/**
 * CustomDOMParser extends the default DOMParser to be able to keep the
 * facilities depending on DocumentImpl as a document type while using a child
 * of DocumentImpl
 * 
 * @author Sebastien Ponce
 */
public class CustomDOMParser extends DOMParser {

    /**
     * gives a CustomDOMParser with custom initialisation
     * 
     * @return a new CustomDOMParser
     */
    public static CustomDOMParser getParser() {
        // creates a new parser and set some features of it
        CustomDOMParser parser = new CustomDOMParser();
        try {
            parser
                    .setFeature(
                            "http://apache.org/xml/features/dom/include-ignorable-whitespace",
                            false);
            parser.setFeature("http://xml.org/sax/features/namespaces", false);
            parser
                    .setFeature(
                            "http://apache.org/xml/features/dom/create-entity-ref-nodes",
                            true);
            parser
                    .setFeature(
                            "http://apache.org/xml/features/continue-after-fatal-error",
                            true);
            parser.setFeature(
                    "http://apache.org/xml/features/validation/dynamic", true);
            parser.setFeature(
                    "http://apache.org/xml/features/dom/defer-node-expansion",
                    false);
            parser.setProperty(
                    "http://apache.org/xml/properties/dom/document-class-name",
                    "ch.cern.lhcb.xmleditor.xerces.DocumentImpl");
        } catch (org.xml.sax.SAXNotSupportedException e) {
            System.out.println("AIE1");
            // nothing to do
        } catch (org.xml.sax.SAXNotRecognizedException e) {
            System.out.println("AIE1");
            // nothing to do
        }
        // creates an error Handler an associates it to the parser
        ErrorHandler errorHandler = new ErrorHandler();
        parser.setErrorHandler(errorHandler);
        // returns
        return parser;
    }

}