/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2006 Sergey Missan
 *
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.Toolkit;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JWindow;

/**
 * Splash window for CESE
 */
class SplashWindow extends JWindow {

	/**
	 * Default constructor
	 * 
	 * @param f
	 *            parent frame
	 */
	public SplashWindow(Frame f) {
		super(f);

		JPanel productPanel = new JPanel(new BorderLayout());

		JLabel title = new JLabel(ResourceManager.getResource("Title") + " "
				+ UserHome.CESE_VERSION_MINOR);
		title.setForeground(Color.white);

		JLabel backdrop = new JLabel(new ImageIcon(ClassLoader
				.getSystemResource("com/simulogic/cese/images/heart.png")));
		backdrop.setLayout(new FlowLayout(FlowLayout.LEFT));
		backdrop.add(title);

		productPanel.add(backdrop, BorderLayout.NORTH);

		getContentPane().add(productPanel, BorderLayout.CENTER);
		pack();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		Dimension labelSize = productPanel.getPreferredSize();
		setLocation(screenSize.width / 2 - (labelSize.width / 2),
				screenSize.height / 2 - (labelSize.height / 2));

		addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				closeSplash();
			}
		});

		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {
				setVisible(true);
			}
		});
	}

	/**
	 * Closes splash window
	 */
	public void closeSplash() {
		setVisible(false);
		dispose();
	}
}
