/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.properties;

import java.awt.BorderLayout;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.TreePath;

import com.simulogic.cese.ModelInfo;

/**
 * The UI for listing, sorting, and setting component properties.
 *  
 */

public class ExportPane extends JPanel {

    private JTree tree;
    private ExportTreeModel treeModel;

    /**
     * Default constructor
     */
    public ExportPane() {
        super(new BorderLayout());

        treeModel = new ExportTreeModel();
        tree = new JTree(treeModel);
        tree.setCellRenderer(new ExportTreeRenderer());

        add(new JScrollPane(tree), BorderLayout.CENTER);
    }

    /**
     * Returns export tree selection
     * 
     * @return export tree selection
     */
    public TreePath[] getExportTreeSelection() {
        return tree.getSelectionPaths();
    }

    /**
     * Sets export tree selection
     * 
     * @param selection export tree selection
     */
    public void setExportTreeSelection(TreePath[] selection) {
        tree.setSelectionPaths(selection);
    }
    
    /**
     * Sets model info
     * 
     * @param info model info
     */
    public void setModelInfo(ModelInfo info) {
        if (info != null) {
            tree.setSelectionInterval(0, 0);
            treeModel.setModelInfo(info);
            treeModel.reload();
        }
    }

}