/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyVetoException;

import javax.help.CSH;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import javax.swing.event.MenuEvent;
import javax.swing.event.MenuListener;

import com.simulogic.dataview.actions.WindowListAction;

/**
 * Menu component that handles the functionality expected of a standard
 * "Windows" menu for MDI applications.
 */
public class WindowMenu extends JMenu {

    private DataDesktop desktop;

    /**
     * Creates new WindowMenu
     * 
     * @param d desktop that contains frames
     */
    public WindowMenu(DataDesktop d) {
        desktop = d;
        setText(ResourceManager.getResource("Window_List"));
        setMnemonic('L');

        addMenuListener(new MenuListener() {

            public void menuCanceled(MenuEvent e) {
            }

            public void menuDeselected(MenuEvent e) {
                removeAll();
            }

            public void menuSelected(MenuEvent e) {
                buildChildMenus();
            }
        });
    }

    /*
     * Sets up the children menus depending
     */
    private void buildChildMenus() {
        ChildMenuItem menu;
        DataFrame frame;

        for (int i = 0; i < desktop.getDataFrames().size(); i++) {
            frame = (DataFrame) desktop.getDataFrames().get(i);
            if (i < 10) {
            menu = new ChildMenuItem(frame);
            menu.setState(frame == desktop.getActiveFrame());
            
                    menu.setAccelerator(KeyStroke.getKeyStroke(Character
                            .forDigit(i, Character.MAX_RADIX), 8));
            menu.addActionListener(new ActionListener() {

                public void actionPerformed(ActionEvent ae) {
                    DataFrame f = ((ChildMenuItem) ae.getSource()).getFrame();
                    f.moveToFront();
                    try {
                        f.setSelected(true);
                    } catch (PropertyVetoException e) {
                    }
                }
            });
            
            menu.setIcon(frame.getFrameIcon());
            add(menu);
            }
            
            if (i >= 10) {
            	addSeparator();
            	JMenuItem item;
            	item = add(new WindowListAction(desktop));
        		item.setAccelerator(KeyStroke.getKeyStroke('I', 8));
        		CSH.setHelpIDString(item, "Commands.Window_List");
            	return;
            }
        }
    }

    /*
     * This JCheckBoxMenuItem descendant is used to track
     */
    class ChildMenuItem extends JCheckBoxMenuItem {

        private DataFrame frame;

        /**
         * Returns menu item for visible frame
         * 
         * @param frame frame for this item
         */
        public ChildMenuItem(DataFrame frame) {
            super(frame.getTitle());
            this.frame = frame;
        }

        /**
         * Returns <code>DataFrame</code> associated with this menu item
         * 
         * @return frame
         */
        public DataFrame getFrame() {
            return frame;
        }
    }
}