/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.legend;

import java.awt.FlowLayout;

import javax.swing.JColorChooser;
import javax.swing.JComboBox;
import javax.swing.UIManager;
import javax.swing.tree.DefaultMutableTreeNode;

import com.simulogic.dataview.DataChannel;
import com.simulogic.dataview.DataGroup;
import com.simulogic.dataview.DataStorage;
import com.simulogic.dataview.DataView;
import com.simulogic.dataview.ResourceManager;
import com.simulogic.dataview.plots.AbstractPlot;
import com.simulogic.dataview.plots.ChannelAttribute;
import com.simulogic.dataview.plots.PlotSymbol;
import com.simulogic.dataview.plots.PlotTypeModel;

/**
 * Editor for the legend tree
 */
public class LegendTreeEditor extends javax.swing.AbstractCellEditor implements
		javax.swing.tree.TreeCellEditor {

	private com.simulogic.dataview.DataChannel chan;

	private com.simulogic.dataview.DataGroup group;

	private com.simulogic.dataview.DataView view;

	private boolean printMode;

	private javax.swing.JColorChooser colorChooser;

	private javax.swing.border.Border selectedBorder;

	private javax.swing.JPanel editingContainer;

	private javax.swing.JButton color;

	private javax.swing.JButton fill;

	private javax.swing.JCheckBox check;

	private javax.swing.JLabel number;

	private javax.swing.JLabel label;

	private javax.swing.JLabel xmark;

	private javax.swing.JComboBox symbolCombo;

	private javax.swing.JComboBox plotCombo;

	private SymbolBoxRenderer symbolRenderer;

	private boolean renderable = false;

	/**
	 * X channel mark
	 */
	public static final String xchan = "<X>";

	/**
	 * Y channel mark
	 */
	public static final String ychan = "<Y>";

	/**
	 * Creates new editor for the legend tree
	 * 
	 * @param v
	 *            data view
	 */
	public LegendTreeEditor(DataView v) {
		view = v;
		selectedBorder = javax.swing.BorderFactory.createLineBorder(UIManager
				.getColor("Tree.selectionBorderColor"), 1);
	}

	/**
	 * Returns editor for the channel
	 * 
	 * @return channel editor
	 */
	public java.lang.Object getCellEditorValue() {
		return chan;
	}

	/**
	 * Returns editing component
	 * 
	 * @param tree
	 *            export tree
	 * @param value
	 *            current value
	 * @param selection
	 *            true if value is selected
	 * @param expanded
	 *            true if value is expanded
	 * @param leaf
	 *            true if value is leaf
	 * @param row
	 *            current row number
	 * @return editing component
	 */
	public java.awt.Component getTreeCellEditorComponent(
			javax.swing.JTree tree, Object value, boolean selection,
			boolean expanded, boolean leaf, int row) {
		try {
			if (editingContainer == null)
				createTreeEditor();

			editingContainer.setBackground(UIManager
					.getColor("Tree.selectionBackground"));
			editingContainer.setBorder(selectedBorder);

			editingContainer.setEnabled(tree.isEnabled());
			number.setFont(tree.getFont());
			label.setFont(tree.getFont());
			xmark.setFont(tree.getFont());

			if (leaf) {
				if (((DefaultMutableTreeNode) value).getUserObject() instanceof com.simulogic.dataview.DataChannel) {
					chan = (DataChannel) ((DefaultMutableTreeNode) value)
							.getUserObject();
					number.setText(((DefaultMutableTreeNode) value).getParent()
							.getIndex((DefaultMutableTreeNode) value)
							+ ":");
					label.setText(chan.getName());
					color.setBackground(chan.getAttribute().getColor());
					symbolRenderer
							.setForeground(chan.getAttribute().getColor());
					fill.setBackground(chan.getAttribute().getFillColor());
					check.setSelected(!chan.getAttribute().isHidden());
					symbolCombo.setSelectedIndex(chan.getAttribute()
							.getSymbol().getType());

					if (chan.getPlot() instanceof com.simulogic.dataview.plots.SymbolPlot) {
						symbolRenderer.setType(chan.getAttribute().getSymbol()
								.getType());
					} else {
						symbolRenderer.setType(100);
					}

					selectPlotType(chan.getPlot());

					DataStorage storage = (DataStorage) tree.getModel();
					switchToX(storage.isXChannel(chan));

					if (printMode && storage.isXChannel(chan))
						return new javax.swing.JPanel();
				}
			} else {
				if (value instanceof com.simulogic.dataview.DataGroup) {
					group = (DataGroup) value;
					label.setText(group.getName());

					if (printMode)
						return new javax.swing.JPanel();

				} else {
					label.setText(ResourceManager.getResource("Legend"));
				}

				number.setVisible(false);
				color.setVisible(false);
				fill.setVisible(false);
				check.setVisible(false);
				xmark.setVisible(false);
				symbolCombo.setVisible(false);
				symbolRenderer.setVisible(false);
				plotCombo.setVisible(false);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}

		editingContainer.revalidate();
		return editingContainer;
	}

	private void colorActionPerformed() {
		colorChooser = new javax.swing.JColorChooser(color.getBackground());

		JColorChooser.createDialog(view,
				ResourceManager.getResource("Channel_color"), true,
				colorChooser, new java.awt.event.ActionListener() {

					public void actionPerformed(java.awt.event.ActionEvent evt) {
						colorOKActionPerformed();
					}
				}, new java.awt.event.ActionListener() {

					public void actionPerformed(java.awt.event.ActionEvent evt) {
						colorCancelActionPerformed();
					}
				}).setVisible(true);
	}

	private void colorOKActionPerformed() {
		chan.getAttribute().setColor(colorChooser.getColor());
		color.setBackground(chan.getAttribute().getColor());
		view.renderPlot();
	}

	private void colorCancelActionPerformed() {
	}

	private void fillActionPerformed() {
		colorChooser = new javax.swing.JColorChooser(fill.getBackground());

		JColorChooser.createDialog(view,
				ResourceManager.getResource("Channel_color"), true,
				colorChooser, new java.awt.event.ActionListener() {

					public void actionPerformed(java.awt.event.ActionEvent evt) {
						fillOKActionPerformed();
					}
				}, new java.awt.event.ActionListener() {

					public void actionPerformed(java.awt.event.ActionEvent evt) {
						fillCancelActionPerformed();
					}
				}).setVisible(true);
	}

	private void fillOKActionPerformed() {
		chan.getAttribute().setFillColor(colorChooser.getColor());
		fill.setBackground(chan.getAttribute().getFillColor());
		view.renderPlot();
	}

	private void fillCancelActionPerformed() {
	}

	private void checkActionPerformed() {
		if (check.isSelected()) {
			chan.getAttribute().setVisiblity(ChannelAttribute.NORMAL_CHANNEL);
		} else {
			chan.getAttribute().setVisiblity(ChannelAttribute.HIDDEN_CHANNEL);
		}
		view.renderPlot();
	}

	private void symbolComboActionPerformed() {
		if (!renderable) {
			if (symbolCombo.getSelectedIndex() != chan.getAttribute()
					.getSymbol().getType()) {
				chan.getAttribute().getSymbol().setType(
						symbolCombo.getSelectedIndex());

				view.renderPlot();
			}
		}
	}

	private void plotComboActionPerformed() {
		if (!renderable) {
			chan.setPlot((AbstractPlot) plotCombo.getSelectedItem());

			this.stopCellEditing();
		}
	}

	private void selectPlotType(AbstractPlot plot) {
		for (int i = 0; i < plotCombo.getItemCount(); i++) {
			if (((AbstractPlot) plotCombo.getItemAt(i)).getName()
					.equalsIgnoreCase(plot.getName()))
				plotCombo.setSelectedIndex(i);
		}
	}

	private void createTreeEditor() {
		editingContainer = new javax.swing.JPanel(new FlowLayout(
				FlowLayout.LEFT));
		editingContainer.setOpaque(true);

		number = new javax.swing.JLabel();
		number.setForeground(UIManager.getColor("Tree.textForeground"));

		color = new javax.swing.JButton();
		color.setPreferredSize(new java.awt.Dimension(13, 13));
		color.setMargin(new java.awt.Insets(0, 0, 0, 0));
		color.setToolTipText(ResourceManager.getResource("Color"));
		color.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				colorActionPerformed();
			}
		});

		fill = new javax.swing.JButton();
		fill.setPreferredSize(new java.awt.Dimension(13, 13));
		fill.setMargin(new java.awt.Insets(0, 0, 0, 0));
		fill.setToolTipText(ResourceManager.getResource("Fill_color"));
		fill.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				fillActionPerformed();
			}
		});

		check = new javax.swing.JCheckBox();
		check.setPreferredSize(new java.awt.Dimension(15, 15));
		check.setMargin(new java.awt.Insets(0, 0, 0, 0));
		check.setToolTipText(ResourceManager.getResource("Visibility"));
		check.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				checkActionPerformed();
			}
		});

		label = new javax.swing.JLabel();
		label.setToolTipText(ResourceManager.getResource("Name"));
		label.setForeground(UIManager.getColor("Tree.textForeground"));

		xmark = new javax.swing.JLabel();
		xmark.setText(LegendTreeEditor.xchan);
		xmark.setForeground(UIManager.getColor("Tree.textForeground"));
		xmark.setToolTipText(ResourceManager.getResource("X_channel"));

		Integer[] symbols = new Integer[PlotSymbol.symbols.length];
		for (int i = 0; i <= PlotSymbol.symbols.length - 1; i++)
			symbols[i] = new Integer(i);

		symbolCombo = new JComboBox(symbols);
		symbolCombo.setRenderer(new SymbolBoxRenderer());
		symbolCombo.setToolTipText(ResourceManager.getResource("Symbol"));

		symbolRenderer = new SymbolBoxRenderer();
		symbolRenderer.setBackground(editingContainer.getBackground());

		plotCombo = new JComboBox(new PlotTypeModel().getPlots());
		plotCombo.setRenderer(new PlotTypeRenderer());
		plotCombo.setToolTipText(ResourceManager.getResource("Plot_type"));

		if (!printMode)
			editingContainer.add(number);

		if (view != null) {
			symbolCombo.addActionListener(new java.awt.event.ActionListener() {

				public void actionPerformed(java.awt.event.ActionEvent evt) {
					symbolComboActionPerformed();
				}
			});

			plotCombo.addActionListener(new java.awt.event.ActionListener() {

				public void actionPerformed(java.awt.event.ActionEvent evt) {
					plotComboActionPerformed();
				}
			});

			if (printMode) {
				editingContainer.add(symbolRenderer);
			} else {
				editingContainer.add(symbolCombo);
			}

			if (!printMode) {
				editingContainer.add(color);
				editingContainer.add(fill);
				editingContainer.add(check);
			}
		}

		editingContainer.add(xmark);
		editingContainer.add(label);

		if (!printMode)
			editingContainer.add(plotCombo);
	}

	private void switchToX(boolean state) {
		plotCombo.setVisible(!state);
		number.setVisible(true);
		color.setVisible(!state);
		check.setVisible(!state);
		symbolRenderer.setVisible(!state);
		if (chan.getPlot() instanceof com.simulogic.dataview.plots.SymbolPlot) {
			symbolCombo.setVisible(!state);
		} else {
			symbolCombo.setVisible(false);
		}

		if (chan.getPlot() instanceof com.simulogic.dataview.plots.ColumnPlot) {
			fill.setVisible(!state);
		} else {
			fill.setVisible(false);
		}
		xmark.setVisible(state);
	}

	public void setPrintMode(boolean p) {
		this.printMode = p;
	}

	public void setRenderable(boolean r) {
		this.renderable = r;
	}

}